@@ -15,6 +15,7 @@ except socket.error as e:
     print >> sys.stderr, "Benno backup already running (%d:%s). Exit" % ( error_code, error_string) 
     sys.exit (0) 
 
+
 def fromConfig(configfile,args):
     for container in Benno.Config(configfile).containers:
         if args.verbose > 0: print >> sys.stderr, "Backup container: %s" % container.id
@@ -40,26 +41,12 @@ def fromConfig(configfile,args):
                 oldhash=f.readline().rstrip()
                 f.close()
             except IOError: pass
-        # tar output
         if args.tarfile and not args.list:
-            if args.tarfile=='-':
-                # open at first container
-                try:
-                    tar
-                except NameError:
-                    tar=tarfile.open(fileobj=sys.stdout,mode='w|')
-            else:
-                tar=tarfile.open(args.tarfile,'a')
-            newesthash=writeTar(repo,oldhash,args,tar)
-            if statusfile:
-                tar.add(statusfile)
-            if not args.tarfile=='-':
-                tar.close()
-        # print filenames
+            # tar output
+            newesthash=tarOutput(args,repo,oldhash,statusfile)
         else:
-            if statusfile:
-                print statusfile
-            newesthash=printFiles(repo,oldhash,args)
+            # filename output
+            newesthash=fileOutput(args,repo,oldhash,statusfile)
         if statusfile:
             f=open(statusfile,'w')
             f.write(newesthash+"\n")
@@ -69,20 +56,19 @@ def fromConfig(configfile,args):
 
 def fromRepo(args):
     repo=Benno.Repo(args.repo)
-    if args.full:
+    if args.increment:
+        statusfile=args.repo+os.sep+'backup.status'
+    else:
         statusfile=False
-    elif args.statusfile:
+    if args.statusfile:
         statusfile=args.statusfile
-    else:    
-        statusfile=repo.path+os.sep+'backup.status'
-        if args.purge_status:
-            try:
-                if args.verbose > 0: print >> sys.stderr, "Remove status file: %s" % statusfile
-                os.remove(statusfile)
-            except:
-                pass
+    if args.purge_status:
+        try:
+            if args.verbose > 0: print >> sys.stderr, "Remove status file: %s" % statusfile
+            os.remove(statusfile)
+        except:
+            pass
     if args.verbose > 0: print >> sys.stderr, "Status file: %s" % statusfile
-
     oldhash=''
     if statusfile:
         try:
@@ -90,8 +76,12 @@ def fromRepo(args):
             oldhash=f.readline().rstrip()
             f.close()
         except IOError: pass
-        print statusfile
-    newesthash=printFiles(repo,oldhash,args)
+    if args.tarfile and not args.list:
+        # tar output
+        newesthash=tarOutput(args,repo,oldhash,statusfile)
+    else:
+        # filename output
+        newesthash=fileOutput(args,repo,oldhash,statusfile)
     if statusfile:
         f=open(statusfile,'w')
         f.write(newesthash+"\n")
@@ -99,10 +89,39 @@ def fromRepo(args):
     return 0
 
 
+
+
+############################################################################
+def fileOutput(args,repo,oldhash,statusfile):
+    if statusfile and os.path.isfile(statusfile):
+        print statusfile
+    newesthash=printFiles(repo,oldhash,args)
+    return newesthash
+ 
+
+############################################################################
+def tarOutput(args,repo,oldhash,statusfile):
+    if args.tarfile=='-':
+        # open at first container
+        try:
+            tar
+        except NameError:
+            tar=tarfile.open(fileobj=sys.stdout,mode='w|')
+    else:
+        tar=tarfile.open(args.tarfile,'a')
+    newesthash=writeTar(repo,oldhash,args,tar)
+    if statusfile and os.path.isfile(statusfile):
+        tar.add(statusfile)
+    if not args.tarfile=='-':
+        tar.close()
+    return newesthash
+
+
 ############################################################################
 def writeTar(repo,oldhash,args,tar):
     journal=Benno.Journal()
-    for box in Benno.Box.GetBoxes(repo.boxstate):
+    #for box in Benno.Box.GetBoxes(repo.boxstate):
+    for box in Benno.Box.GetBoxNames(repo.path):
         for journalfile in box.journalfiles:
             journaldata=Benno.Journalfile(box,journalfile)
             journal.add(journaldata)
@@ -112,18 +131,18 @@ def writeTar(repo,oldhash,args,tar):
         newesthash=newesthashlist[0]
     except IndexError: pass
 
+    tar.add(repo.getBoxstate())
     reposubdir=repo.path
     for jfile in journalfiles:
         currenthash=''
         mailhashes=jfile.getHashes()
         jFileName=jfile.file
-        path,repoJfileName=jFileName.split(reposubdir)
+        path,repoJfileName=jFileName.rsplit(reposubdir,1)
         backupJfileName=reposubdir+repoJfileName
         if args.verbose > 2: print >> sys.stderr, "Add file %s" % backupJfileName
         tar.add(jfile.file,backupJfileName)
         for currenthash in mailhashes:
             if currenthash==oldhash:
-                #tar.close()
                 return newesthash
             file2backup=jfile.box.fileFromHash(currenthash)
             path,repoFileName=file2backup.split(reposubdir)
@@ -136,10 +155,12 @@ def writeTar(repo,oldhash,args,tar):
                 sys.exit("Exit.")
     return newesthash
 
+
 # print full path of repo file
 def printFiles(repo,oldhash,args):
     journal=Benno.Journal()
-    for box in Benno.Box.GetBoxes(repo.boxstate):
+    #for box in Benno.Box.GetBoxes(repo.boxstate):
+    for box in Benno.Box.GetBoxNames(repo.path):
         for journalfile in box.journalfiles:
             journaldata=Benno.Journalfile(box,journalfile)
             journal.add(journaldata)
@@ -149,12 +170,11 @@ def printFiles(repo,oldhash,args):
         newesthash=newesthashlist[0]
     except IndexError: pass
     reposubdir=os.path.basename(repo.path)
+    print repo.getBoxstate()
     for jfile in journalfiles:
         currenthash=''
         mailhashes=jfile.getHashes()
-        jFileName=jfile.file
-        path,repoJfileName=jFileName.split(reposubdir)
-        print "%s" % reposubdir+repoJfileName
+        print "%s" % jfile.file
         for currenthash in mailhashes:
             if currenthash==oldhash:
                 return newesthash
